## 最强板块统计

接口：limit_cpt_list

描述：获取每天涨停股票最多最强的概念板块，可以分析强势板块的轮动，判断资金动向

限量：单次最大2000行数据，可根据股票代码或者日期循环提取全部

积分：8000积分以上每分钟500次，每天总量不限制，具体请参阅积分获取办法 

输入参数

| 名称 | 类型 | 必选 | 描述 |
| --- | --- | --- | --- |
| trade_date | str | N | 交易日期（格式：YYYYMMDD，下同） |
| ts_code | str | N | 板块代码 |
| start_date | str | N | 开始日期 |
| end_date | str | N | 结束日期 |

输出参数

| 名称 | 类型 | 默认显示 | 描述 |
| --- | --- | --- | --- |
| ts_code | str | Y | 板块代码 |
| name | str | Y | 板块名称 |
| trade_date | str | Y | 交易日期 |
| days | int | Y | 上榜天数 |
| up_stat | str | Y | 连板高度 |
| cons_nums | int | Y | 连板家数 |
| up_nums | str | Y | 涨停家数 |
| pct_chg | float | Y | 涨跌幅% |
| rank | str | Y | 板块热点排名 |

接口用法

```python
pro = ts.pro_api()

df = pro.limit_cpt_list(trade_date='20241127')
```

数据样例

```python
ts_code    name      trade_date  days up_stat  cons_nums  up_nums pct_chg  rank
0   885728.TI    人工智能   20241127    18    9天7板         9       27  2.8608     1
```